
{******************************************}
{                                          }
{             FastReport v3.0              }
{           Query params editor            }
{                                          }
{         Copyright (c) 1998-2004          }
{         by Alexander Tzyganenko,         }
{            Fast Reports Inc.             }
{                                          }
{******************************************}

unit frxEditIB_QueryParams;

interface

{$I frx.inc}

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ComCtrls, StdCtrls, Buttons, frxCtrls, ExtCtrls, frxIB_Components
{$IFDEF Delphi6}
, Variants
{$ENDIF};


type
  TfrxIB_ParamsEditorForm = class(TForm)
    ParamsLV: TListView;
    Panel1: TPanel;
    NewB: TButton;
    DeleteB: TButton;
    Panel2: TPanel;
    OkB: TButton;
    CancelB: TButton;
    ValueB: TBitBtn;
    procedure FormDestroy(Sender: TObject);
    procedure DeleteBClick(Sender: TObject);
    procedure ParamsLVEditing(Sender: TObject; Item: TListItem; var AllowEdit: Boolean);
    procedure NewBClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure OkBClick(Sender: TObject);
    procedure FormHide(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure ValueBClick(Sender: TObject);
  private
    FParams: TfrxIB_Params;
    FDeleted: TStrings;
  public
    property Params: TfrxIB_Params read FParams write FParams;
  end;


implementation

{$R *.DFM}

uses
  frxClass,
  frxRes;


{ TfrxParamEditorForm }

procedure TfrxIB_ParamsEditorForm.FormShow(Sender: TObject);
var
  i: Integer;
  Item: TListItem;
begin
  for i := 0 to Params.Count - 1 do
  begin
    Item := ParamsLV.Items.Add;
    Item.Caption := Params[i].Name;
    Item.SubItems.Add(Params[i].Expression);
  end;
  if ParamsLV.Items.Count > 0 then ParamsLV.Selected := ParamsLV.Items[0];
end;

procedure TfrxIB_ParamsEditorForm.FormHide(Sender: TObject);
var
  i: Integer;
  Item: TListItem;
begin
  if ModalResult <> mrOk then Exit;

  // Remove Deleted from Parameters
  for i := 0 to FDeleted.Count-1 do
  begin
    Params.Remove(FDeleted[i]);
  end;

  // Insert/Change Parameters
  for i := 0 to ParamsLV.Items.Count - 1 do
  begin
    Item := ParamsLV.Items[i];
    Params.PutParam(Item.Caption, Item.SubItems[0]);
  end;
end;

procedure TfrxIB_ParamsEditorForm.OkBClick(Sender: TObject);
begin
  ParamsLV.Selected := ParamsLV.Items[0];
end;

procedure TfrxIB_ParamsEditorForm.ValueBClick(Sender: TObject);
var
  s: String;
  item: TListItem;
begin
  item := ParamsLV.Selected;
  if Assigned(item) then
  begin
    s := item.SubItems[0];
    s := TfrxCustomDesigner(Owner).InsertExpression(s);
    if s <> '' then item.SubItems[0] := s;
  end;
end;

procedure TfrxIB_ParamsEditorForm.FormCreate(Sender: TObject);
begin
  FDeleted := TStringList.Create;
  Caption := frxGet(3700);
  OkB.Caption := frxGet(1);
  CancelB.Caption := frxGet(2);
  ParamsLV.Columns[0].Caption := frxResources.Get('qpName');
  ParamsLV.Columns[1].Caption := frxResources.Get('qpValue');
end;

(** Insert a new Paramter in the List *)
procedure TfrxIB_ParamsEditorForm.NewBClick(Sender: TObject);
var item: TListItem;
begin
  item := ParamsLV.Items.Add;
  item.Caption := frxResources.Get('ibNewParam');
  item.SubItems.Add('');
  ParamsLV.Selected := item;
end;

procedure TfrxIB_ParamsEditorForm.ParamsLVEditing(Sender: TObject; Item: TListItem; var AllowEdit: Boolean);
begin
  AllowEdit := true;
end;

(** Delete Parameter entry *)
procedure TfrxIB_ParamsEditorForm.DeleteBClick(Sender: TObject);
var item: TListItem;
begin
  item := ParamsLV.Selected;
  if Assigned(item) then
  begin
    FDeleted.Add(item.Caption);
    item.Delete;
  end;
end;

procedure TfrxIB_ParamsEditorForm.FormDestroy(Sender: TObject);
begin
  FDeleted.Free;
end;

end.
